@@ -1,4 +1,4 @@
-# Copyright (c) 2016-2021 Damon Lynch
+# Copyright (c) 2016-2024 Damon Lynch
 # SPDX - License - Identifier: MIT
 
 """
@@ -7,25 +7,19 @@ Show in File Manager
 Open the system file manager and optionally select files in it.
 """
 
-import argparse
-try:
-    import importlib.metadata as importlib_metadata
-except ImportError:
-    import importlib_metadata
 import os
-from pathlib import Path
 import platform
 import shlex
 import shutil
 import subprocess
 import sys
-from typing import Optional, Union, Sequence, List
 import urllib.parse
+from pathlib import Path
+from typing import List, Optional, Sequence, Union
 
-
-from .constants import FileManagerType, Platform, single_file_only, cannot_open_uris
-from .system import current_platform, is_wsl, is_wsl2, is_wsl1
-from .system import linux, tools, windows
+from .argumentsparse import get_parser
+from .constants import FileManagerType, Platform, single_file_only
+from .system import current_platform, is_wsl, is_wsl1, is_wsl2, linux, tools, windows
 
 _valid_file_manager_probed = False
 _valid_file_manager = None
@@ -183,7 +177,7 @@ def show_in_file_manager(
     else:
         try:
             file_manager_type = _file_manager_type(file_manager)
-        except:
+        except Exception:
             file_manager_type = None
 
     if not (file_manager or is_wsl2):
@@ -414,14 +408,11 @@ def _launch_file_manager(
     """
 
     for u in uris_or_paths:
-        cmd = "{} {}{}".format(file_manager, arg, u)
+        cmd = f"{file_manager} {arg}{u}"
         if verbose:
             print("Executing", cmd)
         # Do not check current_platform here, it makes no sense
-        if platform.system() != "Windows":
-            args = shlex.split(cmd)
-        else:
-            args = cmd
+        args = shlex.split(cmd) if platform.system() != "Windows" else cmd
         proc = subprocess.Popen(args)
         if is_wsl2 and file_manager == "explorer.exe":
             proc.wait()
@@ -484,7 +475,7 @@ class Diagnostics:
         if current_platform == Platform.linux:
             try:
                 self.desktop = linux.linux_desktop()
-            except:
+            except Exception:
                 self.desktop = linux.LinuxDesktop.unknown
         else:
             self.desktop = ""
@@ -498,83 +489,16 @@ class Diagnostics:
             self.wsl_version = ""
 
     def __str__(self) -> str:
-        desktop = (
-            "Linux Desktop: {}\n".format(self.desktop.name) if self.desktop else ""
-        )
-        wsl = "WSL version {}\n".format(self.wsl_version) if self.wsl_version else ""
+        desktop = f"Linux Desktop: {self.desktop.name}\n" if self.desktop else ""
+        wsl = f"WSL version {self.wsl_version}\n" if self.wsl_version else ""
         file_managers = "Stock: {}\nUser's choice: {}\nValid: {}".format(
             self.stock_file_manager, self.user_file_manager, self.valid_file_manager
         )
         return desktop + wsl + file_managers
 
 
-def package_metadata():
-    """
-    Get Python package metadata
-
-    :return: version number and package summary
-    """
-
-    try:
-        version = importlib_metadata.version("show-in-file-manager")
-    except:
-        version = "Unknown version"
-        summary = (
-            "Platform independent Python module to open the system file manager "
-            "and optionally select files in it "
-        )
-
-    else:
-        metadata = importlib_metadata.metadata("show-in-file-manager")
-        summary = metadata["summary"]
-
-    return version, summary
-
-
-def parser_options(formatter_class=argparse.HelpFormatter):
-    """
-    Parse command line options for this script
-
-    :param formatter_class: one of 4 argparse formatting classes
-    :return: argparse.ArgumentParser
-    """
-
-    version, summary = package_metadata()
-
-    parser = argparse.ArgumentParser(
-        prog="showinfilemanager", description=summary, formatter_class=formatter_class
-    )
-
-    parser.add_argument(
-        "--version", action="version", version="%(prog)s {}".format(version)
-    )
-
-    parser.add_argument("-f", "--file-manager", help="file manager to run")
-
-    parser.add_argument(
-        "-s",
-        "--select-folder",
-        action="store_true",
-        help="select folder instead of displaying its contents",
-    )
-
-    parser.add_argument(
-        "--verbose", action="store_true", help="display command being run to stdout"
-    )
-
-    parser.add_argument(
-        "--debug", action="store_true", help="output debugging information to stdout"
-    )
-
-    parser.add_argument(
-        "path", nargs="*", help="zero or more URIs or paths of files or directories"
-    )
-
-    return parser
-
-
 def main() -> None:
-    parser = parser_options()
+    parser = get_parser()
 
     args = parser.parse_args()
 
